@@ -1,7 +1,7 @@
 package Weed::Parse::String;
 use Weed::Perl;
 
-our $VERSION = '0.0079';
+our $VERSION = '0.008';
 
 use Weed::RegularExpressions '$_string';
 
@@ -9,7 +9,7 @@ use Exporter 'import';
 
 our @EXPORT_OK = qw.parseString string.;
 
-sub parseString { &string( \$_[0] ) }
+sub parseString { &string( $_[0] ) }
 
 sub string {
 	return $1 if ${$_[0]} =~ m.$_string.gc;
