@@ -1,16 +1,16 @@
 package Weed::Tie::Field;
 use Weed::Perl;
 
-our $VERSION = '0.0078';
+our $VERSION = '0.0079';
 
 use Tie::Scalar;
 use base 'Tie::StdScalar';
 
 sub TIESCALAR { bless \$_[1], $_[0] }
 
-sub FETCH { ${ $_[0] }->getClone }
+sub FETCH { ${ $_[0] }->getClone->getValue }
 
-sub STORE { ${ $_[0] }->setValue($_[1]) }
+sub STORE { ${ $_[0] }->setValue( $_[1] ) }
 
 1;
 __END__
