@@ -1,7 +1,7 @@
 package Weed::Tie::Value::Vector;
 use Weed;
 
-our $VERSION = '0.0081';
+our $VERSION = '0.0082';
 
 use base 'Tie::Array';
 
@@ -9,12 +9,16 @@ use Scalar::Util 'weaken';
 
 use Weed::Parse::Double 'double';
 
-sub getParent { $_[0]->{parent} }
-sub getValue  { $_[0]->{value} }
+sub new {
+	tie my (@array), $_[0], $_[1];
+	return \@array;
+}
+
+#sub getParent { $_[0]->{parent} }
+sub getValue { $_[0]->{parent}->getValue }
 
 sub TIEARRAY {
 	my $this = bless {
-		value  => $_[1]->getValue,
 		parent => $_[1],
 		fields => {},
 	  },
@@ -27,19 +31,19 @@ sub TIEARRAY {
 
 sub STORE {
 	return X3DMessage->IndexOutOfRange( 3, @_ )
-	  unless defined $_[0]->{value}->set1Value( $_[1], double( \"$_[2]" ) || 0 );
+	  unless defined $_[0]->getValue->set1Value( $_[1], double( \"$_[2]" ) || 0 );
 }
 
 sub FETCH {
 	return X3DMessage->IndexOutOfRange( 3, @_ ) unless $_[0]->EXISTS( $_[1] );
-	$_[0]->{value}->[ $_[1] ]
+	$_[0]->getValue->[ $_[1] ]
 }
 
-sub FETCHSIZE { $_[0]->{value}->elementCount }
-sub EXISTS    { exists $_[0]->{value}->[ $_[1] ] }
+sub FETCHSIZE { $_[0]->getValue->elementCount }
+sub EXISTS    { exists $_[0]->getValue->[ $_[1] ] }
 
 sub STORESIZE { warn "STORESIZE" }
-sub CLEAR     { $_[0]->{value}->clear }
+sub CLEAR     { $_[0]->getValue->clear }
 sub DELETE    { warn "DELETE   " }
 
 sub POP     { warn "POP 	" }
