@@ -1,7 +1,7 @@
 package Weed::Values::Vec2;
 use Weed::Perl;
 
-our $VERSION = '0.0079';
+our $VERSION = '0.008';
 
 use Package::Alias X3DVec2 => __PACKAGE__;
 
@@ -18,6 +18,10 @@ sub getX { $_[0]->[0] }
 
 sub getY { $_[0]->[1] }
 
+sub x : lvalue { $_[0]->[0] }
+
+sub y : lvalue { $_[0]->[1] }
+
 sub negate {
 	my ($a) = @_;
 	return $a->new( [
@@ -28,16 +32,14 @@ sub negate {
 
 sub add {
 	my ( $a, $b ) = @_;
-	return ref $b ?
-	  $a->new( [
-			$a->[0] + $b->[0],
-			$a->[1] + $b->[1],
-		] )
-	  :
-	  $a->new( [
-			$a->[0] + $b,
-			$a->[1] + $b,
-	  ] );
+	return
+	  $a->new( [ ref $b ? (
+				$a->[0] + $b->[0],
+				$a->[1] + $b->[1],
+			  ) : (
+				$a->[0] + $b,
+				$a->[1] + $b,
+			  ) ] );
 }
 
 use overload '+=' => sub {
@@ -83,16 +85,14 @@ use overload '-=' => sub {
 
 sub multiply {
 	my ( $a, $b ) = @_;
-	return ref $b ?
-	  $a->new( [
-			$a->[0] * $b->[0],
-			$a->[1] * $b->[1],
-		] )
-	  :
-	  $a->new( [
-			$a->[0] * $b,
-			$a->[1] * $b,
-	  ] );
+	return
+	  $a->new( [ ref $b ? (
+				$a->[0] * $b->[0],
+				$a->[1] * $b->[1],
+			  ) : (
+				$a->[0] * $b,
+				$a->[1] * $b,
+			  ) ] );
 }
 
 use overload '*=' => sub {
